﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Phidgets;
using Phidgets.Events;

namespace PhidgetIKToServo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        Phidgets.InterfaceKit ik = new Phidgets.InterfaceKit(); // The basic interface kit object that controls the actual hardware
        Phidgets.Servo servo = new Phidgets.Servo(); // The basic servo object that controls the actual hardware

        public MainWindow()
        {
            InitializeComponent();
            ik.Attach += new AttachEventHandler(ik_Attach);  // Invoked when the interface kit is actually plugged in (Attached)
            ik.open();
            servo.Attach += new AttachEventHandler(servo_Attach);   // Invoked when the servo is actually plugged in (Attached)
            servo.open();
        }

         // The servo is attached. Add callbacks, enable the slider, and set it all to position 0  
        void servo_Attach(object sender, AttachEventArgs e)
        {
            this.Dispatcher.Invoke(new Action(delegate()
            {
                printMessage("Servo Attached"); 
                servo.Detach += new DetachEventHandler(servo_Detach);  // generic phdiget callbacks
            }));
        }

        // The interfacekit is attached.  
        void ik_Attach(object sender, AttachEventArgs e)
        {
            this.Dispatcher.Invoke(new Action(delegate()
            {
                printMessage("InterfaceKit Attached");
                ik.Detach += new DetachEventHandler(ik_Detach);
                ik.SensorChange += new SensorChangeEventHandler(ik_SensorChange);
            }));
        }

        // The servo is detached. Disable the slider and remove callbacks  
        void servo_Detach(object sender, DetachEventArgs e)
        {
            this.Dispatcher.Invoke(new Action(delegate()
            {
                printMessage("Servo Detached");
                servo.Detach -= new DetachEventHandler(servo_Detach);
            }));
        }

        // The InterfaceKit is detached. Disable various input controls and remove callbacks  
        void ik_Detach(object sender, DetachEventArgs e)
        {
            this.Dispatcher.Invoke(new Action(delegate()
            {
                printMessage("InterfaceKit Detached");
                ik.Detach -= new DetachEventHandler(ik_Detach);
                ik.SensorChange -=  new SensorChangeEventHandler(ik_SensorChange);
            }));
        }

        // A phidget's sensor value (which ranges between 0-1000) has changed
        void ik_SensorChange(object sender, SensorChangeEventArgs e)
        {
          
            if (e.Index != 0) return; // Ignore all but the first sensor
            this.Dispatcher.Invoke(new Action(delegate()
            {
                printMessage("InterfaceKit Sensor 0 event at " + e.Value);
                if (this.servo.Attached)
                    this.servo.servos[0].Position = this.ik.sensors[e.Index].Value / 1000.0 * 180.0;
            }));
        }

        // Put some feedback in the title bar
        private void printMessage(string msg)
        {
            this.listBox1.Items.Insert(0, msg);
        }
    }
}
